==> galeon-1.3.0.tar.bz2: galeon-1.3.0/utils/galeon-marshal.h <==

#ifndef __galeon_marshal_MARSHAL_H__
#define __galeon_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:VOID (./galeon-marshal.list:1) */
#define galeon_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:STRING (./galeon-marshal.list:2) */
#define galeon_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:OBJECT (./galeon-marshal.list:3) */
#define galeon_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:OBJECT,OBJECT,INT (./galeon-marshal.list:4) */
extern void galeon_marshal_VOID__OBJECT_OBJECT_INT (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);

/* VOID:OBJECT,STRING,INT (./galeon-marshal.list:5) */
extern void galeon_marshal_VOID__OBJECT_STRING_INT (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);

/* VOID:OBJECT,INT (./galeon-marshal.list:6) */
extern void galeon_marshal_VOID__OBJECT_INT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:OBJECT,INT,INT (./galeon-marshal.list:7) */
extern void galeon_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:POINTER,INT (./galeon-marshal.list:8) */
extern void galeon_marshal_VOID__POINTER_INT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:STRING,INT,INT (./galeon-marshal.list:9) */
extern void galeon_marshal_VOID__STRING_INT_INT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:STRING,INT (./galeon-marshal.list:10) */
extern void galeon_marshal_VOID__STRING_INT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:STRING,STRING (./galeon-marshal.list:11) */
extern void galeon_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* INT:STRING (./galeon-marshal.list:12) */
extern void galeon_marshal_INT__STRING (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

/* VOID:INT,INT (./galeon-marshal.list:13) */
extern void galeon_marshal_VOID__INT_INT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* INT:OBJECT (./galeon-marshal.list:14) */
extern void galeon_marshal_INT__OBJECT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

G_END_DECLS

#endif /* __galeon_marshal_MARSHAL_H__ */

==> galeon-1.3.6.tar.bz2: galeon-1.3.6/utils/galeon-marshal.h <==

#ifndef __galeon_marshal_MARSHAL_H__
#define __galeon_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:VOID (./galeon-marshal.list:1) */
#define galeon_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:STRING (./galeon-marshal.list:2) */
#define galeon_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:OBJECT (./galeon-marshal.list:3) */
#define galeon_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:OBJECT,OBJECT,INT (./galeon-marshal.list:4) */
extern void galeon_marshal_VOID__OBJECT_OBJECT_INT (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);

/* VOID:OBJECT,STRING,INT (./galeon-marshal.list:5) */
extern void galeon_marshal_VOID__OBJECT_STRING_INT (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);

/* VOID:OBJECT,INT (./galeon-marshal.list:6) */
extern void galeon_marshal_VOID__OBJECT_INT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:OBJECT,INT,INT (./galeon-marshal.list:7) */
extern void galeon_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:POINTER,INT (./galeon-marshal.list:8) */
extern void galeon_marshal_VOID__POINTER_INT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:STRING,INT,INT (./galeon-marshal.list:9) */
extern void galeon_marshal_VOID__STRING_INT_INT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:STRING,INT (./galeon-marshal.list:10) */
extern void galeon_marshal_VOID__STRING_INT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:STRING,STRING (./galeon-marshal.list:11) */
extern void galeon_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* INT:STRING (./galeon-marshal.list:12) */
extern void galeon_marshal_INT__STRING (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

/* VOID:INT,INT (./galeon-marshal.list:13) */
extern void galeon_marshal_VOID__INT_INT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:INT,INT,INT (./galeon-marshal.list:14) */
extern void galeon_marshal_VOID__INT_INT_INT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* INT:OBJECT (./galeon-marshal.list:15) */
extern void galeon_marshal_INT__OBJECT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

G_END_DECLS

#endif /* __galeon_marshal_MARSHAL_H__ */
